@@ -9,7 +9,7 @@ def tracer(sql, params):
     print("SQL: {} - params: {}".format(sql, params))
 
 
-def connect_db(args):
+def connect(args):
     if not os.path.exists(args.database) and ":memory:" not in args.database:
         log.error(
             f"Database file '{args.database}' does not exist. Create one with lb extract / lb tubeadd / lb tabsadd."
@@ -19,11 +19,7 @@ def connect_db(args):
     return sqlite_utils.Database(args.database, tracer=tracer if args.verbose > 1 else None)  # type: ignore
 
 
-def fetchall_dict(con, *args):
-    return [dict(r) for r in con.execute(*args).fetchall()]
-
-
-def optimize_db(args):
+def optimize(args):
     print("Optimizing database")
     db: sqlite_utils.Database = args.db
     columns = db["media"].columns_dict
@@ -45,3 +41,16 @@ def optimize_db(args):
     with db.conn:
         db["media"].optimize()  # type: ignore
     db.vacuum()
+
+
+def fts_quote(l):
+    fts_words = [" NOT ", " AND ", " OR ", "*", ":", "NEAR("]
+    return [s if any([r in s for r in fts_words]) else '"' + s + '"' for s in l]
+
+
+def fts_search(args, bindings):
+    bindings["query"] = " AND ".join(fts_quote(args.include))
+    if args.exclude:
+        bindings["query"] += " NOT " + " NOT ".join(fts_quote(args.exclude))
+    table = "(" + args.db["media"].search_sql() + ")"  #  include_rank=True
+    return table
