@@ -1,12 +1,13 @@
 import enum, os, re
 from pathlib import Path
-from tempfile import gettempdir
+from tempfile import gettempdir, mkdtemp
 
 from xklb import utils
 
 FAKE_SUBTITLE = os.path.join(gettempdir(), "sub.srt")  # https://github.com/skorokithakis/catt/issues/393
 CAST_NOW_PLAYING = os.path.join(gettempdir(), "catt_playing")
 DEFAULT_MPV_SOCKET = os.path.join(gettempdir(), "mpv_socket")
+SUB_TEMP_DIR = mkdtemp()
 
 
 class Frequency(enum.Enum):
@@ -82,7 +83,7 @@ def get_media_files(path, audio=False):
     FFMPEG_ENDINGS = FFMPEG_DEMUXERS.split("|")
     video_files = []
     for f in Path(path).resolve().rglob("*"):
-        if f.is_file() and (f.suffix.lower()[1:] in FFMPEG_ENDINGS):
+        if f.is_file() and (f.suffix[1:].lower() in FFMPEG_ENDINGS):
             video_files.append(str(f))
 
     return video_files
