@@ -13,17 +13,7 @@ import pandas as pd
 from tabulate import tabulate
 
 from xklb import paths, utils
-from xklb.utils import (
-    SC,
-    SQLITE_PARAM_LIMIT,
-    cmd,
-    cmd_interactive,
-    human_time,
-    log,
-    os_bg_kwargs,
-    print_query,
-    resize_col,
-)
+from xklb.utils import SC, SQLITE_PARAM_LIMIT, cmd, cmd_interactive, human_time, log, os_bg_kwargs, resize_col
 
 
 def mv_to_keep_folder(args, media_file: str):
@@ -39,8 +29,8 @@ def mv_to_keep_folder(args, media_file: str):
 
     keep_path.mkdir(exist_ok=True)
     new_path = shutil.move(media_file, keep_path)
-    with args.db:
-        args.db.execute("UPDATE media set path = ? where path = ?", [new_path, media_file])
+    with args.db.conn:
+        args.db.conn.execute("UPDATE media set path = ? where path = ?", [new_path, media_file])
 
 
 def mark_media_watched(args, files):
@@ -138,11 +128,13 @@ def delete_media(args, media_file: str):
 
 
 def delete_playlists(args, playlists):
-    with args.db:
-        args.db.execute(
+    with args.db.conn:
+        args.db.conn.execute(
             "delete from media where playlist_path in (" + ",".join(["?"] * len(playlists)) + ")", (*playlists,)
         )
-        args.db.execute("delete from playlists where path in (" + ",".join(["?"] * len(playlists)) + ")", (*playlists,))
+        args.db.conn.execute(
+            "delete from playlists where path in (" + ",".join(["?"] * len(playlists)) + ")", (*playlists,)
+        )
 
 
 def get_ordinal_media(args, path):
@@ -178,7 +170,7 @@ def get_ordinal_media(args, path):
         if not args.play_in_order > 2:
             bindings.extend(args.sql_filter_bindings)
 
-        similar_videos = utils.single_column_tolist(args.db.execute(query, bindings).fetchall(), "path")  # type: ignore
+        similar_videos = [d["path"] for d in args.db.query(query, bindings)]
         log.debug(similar_videos)
 
         if len(similar_videos) > 999 or len(similar_videos) == total_media:
@@ -313,14 +305,15 @@ def socket_play(args, m):
 
 def local_player(args, m, media_file):
     player = generic_player(args)
+    mpv = which("mpv.com") or which("mpv")
 
     if args.player:
         player = args.player
         args.player_need_sleep = False
 
-    elif which("mpv"):
+    elif mpv:
         args.player_need_sleep = False
-        player = [which("mpv")]
+        player = [mpv]
         if args.action in [SC.listen, SC.tubelisten]:
             player.extend([f"--input-ipc-server={args.mpv_socket}", "--no-video", "--keep-open=no", "--really-quiet"])
         elif args.action in [SC.watch, SC.tubewatch]:
@@ -349,6 +342,9 @@ def local_player(args, m, media_file):
     if args.action == SC.watch:
         if m["subtitle_count"] > 0:
             player.extend(args.player_args_when_sub)
+        elif Path(media_file).stat().st_size > 500 * 1000000:  # 500 MB
+            # player.extend(args.player_args_when_no_sub_big_file) # TODO: if people complain fix this
+            pass
         else:
             player.extend(args.player_args_when_no_sub)
 
@@ -385,11 +381,7 @@ def printer(args, query, bindings):
     db_resp.dropna(axis="columns", how="all", inplace=True)
 
     if args.verbose > 1 and args.cols and "*" in args.cols:
-        import rich
-
         breakpoint()
-        for t in db_resp.to_dict(orient="records"):
-            rich.print(t)
 
     if db_resp.empty or len(db_resp) == 0:
         print("No media found")
