@@ -8,7 +8,6 @@ from typing import Union
 import humanize
 import numpy as np
 import pandas as pd
-import psutil
 from IPython.core import ultratb
 from IPython.terminal.debugger import TerminalPdb
 from pychromecast import discovery
@@ -236,19 +235,6 @@ def compile_query(query, *args):
     return query
 
 
-def print_query(query, bindings):
-    return re.sub(r"\n\s+", r"\n", compile_query(query, *bindings))
-
-
-def single_column_tolist(array_to_unpack, column_name: Union[str, int] = 1):
-    return list(
-        map(
-            lambda x: x[column_name],
-            array_to_unpack,
-        )
-    )
-
-
 def dict_filter_bool(kwargs):
     return {k: v for k, v in kwargs.items() if v}
 
@@ -308,17 +294,6 @@ def human_time(seconds):
         return humanize.precisedelta(timedelta(seconds=int(seconds)), minimum_unit="minutes")
 
 
-def pkill(*command, strict=True):
-    found = 0
-    for process in psutil.process_iter():
-        if process.cmdline() == command:
-            process.terminate()
-            found = 1
-            break
-    if strict and found == 0:
-        raise Exception("Process not found")
-
-
 class argparse_dict(argparse.Action):
     def __call__(self, parser, args, values, option_string=None):
         try:
